@@ -1,8 +1,4 @@
-"""
-__init__
-"""
-
-__version__ = "0.1.0"
+__version__ = "0.1.2"
 __author__  = "Khaled Al Moulla"
 
 from .arve import ARVE
