@@ -1,5 +1 @@
-"""
-__init__
-"""
-
 from .add_planet import add_planet
\ No newline at end of file
